@@ -1,8 +1,12 @@
 use CairoX::Sweet::Standard;
+use strict;
+use warnings;
 
 # PODNAME: CairoX::Sweet::Role::PathCommand
 
 role CairoX::Sweet::Role::PathCommand using Moose {
+
+    our $VERSION = '0.0107'; # VERSION
     requires 'location', 'move_location';
 }
 
@@ -20,7 +24,7 @@ CairoX::Sweet::Role::PathCommand
 
 =head1 VERSION
 
-Version 0.0106, released 2015-01-19.
+Version 0.0107, released 2015-03-19.
 
 =head1 SOURCE
 
