@@ -1,9 +1,12 @@
 use 5.14.0;
+use strict;
+use warnings;
 
-our $VERSION = '0.0106'; # VERSION
 
 package CairoX::Sweet::Standard {
 
+    our $VERSION = '0.0107'; # VERSION
+
     use base 'Moops';
     use Types::CairoX::Sweet();
     use MooseX::StrictConstructor();
@@ -39,7 +42,7 @@ CairoX::Sweet::Standard
 
 =head1 VERSION
 
-Version 0.0106, released 2015-01-19.
+Version 0.0107, released 2015-03-19.
 
 =head1 SOURCE
 
